/**
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.apache.commons.httpclient.protocol;

import java.io.IOException;
import java.security.cert.X509Certificate;

import javax.net.ssl.SSLException;
import javax.net.ssl.SSLSession;
import javax.net.ssl.SSLSocket;

/**
 * An implementation of {@link X509HostnameVerifier} that allows all host names.
 * That is, verification of the host name is not done at all.
 */
public class AllowAllHostnameVerifier implements X509HostnameVerifier {

    public boolean verify(String host, SSLSession session) {
        return true;
    }

    public void verify(String host, SSLSocket ssl) throws IOException {
    }

    public void verify(String host, X509Certificate cert) throws SSLException {
    }

    public void verify(String host, String[] cns, String[] subjectAlts) throws SSLException {
    }
    
    @Override
    public final String toString() {
        return "ALLOW_ALL";
    }
   
}
